# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: iam/v1/iam.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api import user_pb2 as api_dot_user__pb2
from alphausblue.api import apiclient_pb2 as api_dot_apiclient__pb2
from alphausblue.api import rbac_pb2 as api_dot_rbac__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='iam/v1/iam.proto',
  package='blueapi.iam.v1',
  syntax='proto3',
  serialized_options=b'\n\025cloud.alphaus.api.iamB\010IamProtoZ\"github.com/alphauslabs/blueapi/iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10iam/v1/iam.proto\x12\x0e\x62lueapi.iam.v1\x1a\x0e\x61pi/user.proto\x1a\x13\x61pi/apiclient.proto\x1a\x0e\x61pi/rbac.proto\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x0f\n\rWhoAmIRequest\"\x12\n\x10ListUsersRequest\"\x1c\n\x0eGetUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\"T\n\x11\x43reateUserRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08nickName\x18\x04 \x01(\t\"\x1f\n\x11\x44\x65leteUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x17\n\x15ListApiClientsRequest\"&\n\x16\x43reateApiClientRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"$\n\x16\x44\x65leteApiClientRequest\x12\n\n\x02id\x18\x01 \x01(\t\")\n\x16ListPermissionsRequest\x12\x0f\n\x07subUser\x18\x01 \x01(\t\"G\n\x17ListPermissionsResponse\x12,\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x17.blueapi.api.Permission\"%\n\x10ListRolesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\"5\n\x11ListRolesResponse\x12 \n\x05roles\x18\x01 \x03(\x0b\x32\x11.blueapi.api.Role\"I\n\x11\x43reateRoleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t\"Z\n\x11UpdateRoleRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07newName\x18\x03 \x01(\t\x12\x13\n\x0bpermissions\x18\x04 \x03(\t\"4\n\x11\x44\x65leteRoleRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\".\n\x1bListUserRoleMappingsRequest\x12\x0f\n\x07subUser\x18\x01 \x01(\t\"V\n\x1cListUserRoleMappingsResponse\x12\x36\n\x10userRoleMappings\x18\x01 \x03(\x0b\x32\x1c.blueapi.api.UserRoleMapping\"*\n\x07MapRole\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"W\n\x1c\x43reateUserRoleMappingRequest\x12\x0f\n\x07subUser\x18\x01 \x01(\t\x12&\n\x05roles\x18\x02 \x03(\x0b\x32\x17.blueapi.iam.v1.MapRole\"Q\n\x1d\x43reateUserRoleMappingResponse\x12\x0f\n\x07success\x18\x01 \x03(\t\x12\x0e\n\x06\x66\x61iled\x18\x02 \x03(\t\x12\x0f\n\x07\x66ilters\x18\x03 \x03(\t\"W\n\x1cUpdateUserRoleMappingRequest\x12\x0f\n\x07subUser\x18\x01 \x01(\t\x12&\n\x05roles\x18\x02 \x03(\x0b\x32\x17.blueapi.iam.v1.MapRole\"Q\n\x1dUpdateUserRoleMappingResponse\x12\x0f\n\x07success\x18\x01 \x03(\t\x12\x0e\n\x06\x66\x61iled\x18\x02 \x03(\t\x12\x0f\n\x07\x66ilters\x18\x03 \x03(\t\"R\n\x08IpFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05scope\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"\x16\n\x14ListIpFiltersRequest\"W\n\x15\x43reateIpFilterRequest\x12\r\n\x05value\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08rootUser\x18\x03 \x01(\t\x12\x0f\n\x07subUser\x18\x04 \x01(\t\"#\n\x15\x44\x65leteIpFilterRequest\x12\n\n\x02id\x18\x01 \x01(\t2\xeb\x11\n\x03Iam\x12R\n\x06WhoAmI\x12\x1d.blueapi.iam.v1.WhoAmIRequest\x1a\x11.blueapi.api.User\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/iam/v1/whoami\x12Y\n\tListUsers\x12 .blueapi.iam.v1.ListUsersRequest\x1a\x11.blueapi.api.User\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/iam/v1/users0\x01\x12X\n\x07GetUser\x12\x1e.blueapi.iam.v1.GetUserRequest\x1a\x11.blueapi.api.User\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/iam/v1/users/{id}\x12\\\n\nCreateUser\x12!.blueapi.iam.v1.CreateUserRequest\x1a\x11.blueapi.api.User\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/iam/v1/users:\x01*\x12\x63\n\nDeleteUser\x12!.blueapi.iam.v1.DeleteUserRequest\x1a\x16.google.protobuf.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14*\x12/iam/v1/users/{id}\x12m\n\x0eListApiClients\x12%.blueapi.iam.v1.ListApiClientsRequest\x1a\x16.blueapi.api.ApiClient\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/iam/v1/apiclients0\x01\x12p\n\x0f\x43reateApiClient\x12&.blueapi.iam.v1.CreateApiClientRequest\x1a\x16.blueapi.api.ApiClient\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/iam/v1/apiclients:\x01*\x12r\n\x0f\x44\x65leteApiClient\x12&.blueapi.iam.v1.DeleteApiClientRequest\x1a\x16.google.protobuf.Empty\"\x1f\x82\xd3\xe4\x93\x02\x19*\x17/iam/v1/apiclients/{id}\x12\x7f\n\x0fListPermissions\x12&.blueapi.iam.v1.ListPermissionsRequest\x1a\'.blueapi.iam.v1.ListPermissionsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/iam/v1/permissions\x12g\n\tListRoles\x12 .blueapi.iam.v1.ListRolesRequest\x1a!.blueapi.iam.v1.ListRolesResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/iam/v1/roles\x12\\\n\nCreateRole\x12!.blueapi.iam.v1.CreateRoleRequest\x1a\x11.blueapi.api.Role\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/iam/v1/roles:\x01*\x12o\n\nUpdateRole\x12!.blueapi.iam.v1.UpdateRoleRequest\x1a\x11.blueapi.api.Role\"+\x82\xd3\xe4\x93\x02%\x1a /iam/v1/roles/{namespace}/{name}:\x01*\x12q\n\nDeleteRole\x12!.blueapi.iam.v1.DeleteRoleRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"* /iam/v1/roles/{namespace}/{name}\x12\x8c\x01\n\x14ListUserRoleMappings\x12+.blueapi.iam.v1.ListUserRoleMappingsRequest\x1a,.blueapi.iam.v1.ListUserRoleMappingsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/iam/v1/userroles\x12\x92\x01\n\x15\x43reateUserRoleMapping\x12,.blueapi.iam.v1.CreateUserRoleMappingRequest\x1a-.blueapi.iam.v1.CreateUserRoleMappingResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/iam/v1/userroles:\x01*\x12\x92\x01\n\x15UpdateUserRoleMapping\x12,.blueapi.iam.v1.UpdateUserRoleMappingRequest\x1a-.blueapi.iam.v1.UpdateUserRoleMappingResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x1a\x11/iam/v1/userroles:\x01*\x12l\n\rListIpFilters\x12$.blueapi.iam.v1.ListIpFiltersRequest\x1a\x18.blueapi.iam.v1.IpFilter\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/iam/v1/ipfilters0\x01\x12o\n\x0e\x43reateIpFilter\x12%.blueapi.iam.v1.CreateIpFilterRequest\x1a\x18.blueapi.iam.v1.IpFilter\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/iam/v1/ipfilters:\x01*\x12o\n\x0e\x44\x65leteIpFilter\x12%.blueapi.iam.v1.DeleteIpFilterRequest\x1a\x16.google.protobuf.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18*\x16/iam/v1/ipfilters/{id}\x1a\x8d\x01\x92\x41\x89\x01\x12:(BETA) IAM API. Base URL: https://api.alphaus.cloud/m/blue\x1aK\n\x12Service definition\x12\x35https://github.com/alphauslabs/blueapi/tree/main/iam/BE\n\x15\x63loud.alphaus.api.iamB\x08IamProtoZ\"github.com/alphauslabs/blueapi/iamb\x06proto3'
  ,
  dependencies=[api_dot_user__pb2.DESCRIPTOR,api_dot_apiclient__pb2.DESCRIPTOR,api_dot_rbac__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_WHOAMIREQUEST = _descriptor.Descriptor(
  name='WhoAmIRequest',
  full_name='blueapi.iam.v1.WhoAmIRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=211,
)


_LISTUSERSREQUEST = _descriptor.Descriptor(
  name='ListUsersRequest',
  full_name='blueapi.iam.v1.ListUsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=231,
)


_GETUSERREQUEST = _descriptor.Descriptor(
  name='GetUserRequest',
  full_name='blueapi.iam.v1.GetUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.iam.v1.GetUserRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=261,
)


_CREATEUSERREQUEST = _descriptor.Descriptor(
  name='CreateUserRequest',
  full_name='blueapi.iam.v1.CreateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.iam.v1.CreateUserRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='blueapi.iam.v1.CreateUserRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='blueapi.iam.v1.CreateUserRequest.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nickName', full_name='blueapi.iam.v1.CreateUserRequest.nickName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=347,
)


_DELETEUSERREQUEST = _descriptor.Descriptor(
  name='DeleteUserRequest',
  full_name='blueapi.iam.v1.DeleteUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.iam.v1.DeleteUserRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=380,
)


_LISTAPICLIENTSREQUEST = _descriptor.Descriptor(
  name='ListApiClientsRequest',
  full_name='blueapi.iam.v1.ListApiClientsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=405,
)


_CREATEAPICLIENTREQUEST = _descriptor.Descriptor(
  name='CreateApiClientRequest',
  full_name='blueapi.iam.v1.CreateApiClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.iam.v1.CreateApiClientRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=445,
)


_DELETEAPICLIENTREQUEST = _descriptor.Descriptor(
  name='DeleteApiClientRequest',
  full_name='blueapi.iam.v1.DeleteApiClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.iam.v1.DeleteApiClientRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=483,
)


_LISTPERMISSIONSREQUEST = _descriptor.Descriptor(
  name='ListPermissionsRequest',
  full_name='blueapi.iam.v1.ListPermissionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subUser', full_name='blueapi.iam.v1.ListPermissionsRequest.subUser', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=526,
)


_LISTPERMISSIONSRESPONSE = _descriptor.Descriptor(
  name='ListPermissionsResponse',
  full_name='blueapi.iam.v1.ListPermissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='blueapi.iam.v1.ListPermissionsResponse.permissions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=599,
)


_LISTROLESREQUEST = _descriptor.Descriptor(
  name='ListRolesRequest',
  full_name='blueapi.iam.v1.ListRolesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='blueapi.iam.v1.ListRolesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=638,
)


_LISTROLESRESPONSE = _descriptor.Descriptor(
  name='ListRolesResponse',
  full_name='blueapi.iam.v1.ListRolesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='blueapi.iam.v1.ListRolesResponse.roles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=693,
)


_CREATEROLEREQUEST = _descriptor.Descriptor(
  name='CreateRoleRequest',
  full_name='blueapi.iam.v1.CreateRoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.iam.v1.CreateRoleRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='blueapi.iam.v1.CreateRoleRequest.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='blueapi.iam.v1.CreateRoleRequest.permissions', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=768,
)


_UPDATEROLEREQUEST = _descriptor.Descriptor(
  name='UpdateRoleRequest',
  full_name='blueapi.iam.v1.UpdateRoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='blueapi.iam.v1.UpdateRoleRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.iam.v1.UpdateRoleRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='newName', full_name='blueapi.iam.v1.UpdateRoleRequest.newName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='blueapi.iam.v1.UpdateRoleRequest.permissions', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=860,
)


_DELETEROLEREQUEST = _descriptor.Descriptor(
  name='DeleteRoleRequest',
  full_name='blueapi.iam.v1.DeleteRoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='blueapi.iam.v1.DeleteRoleRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.iam.v1.DeleteRoleRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=914,
)


_LISTUSERROLEMAPPINGSREQUEST = _descriptor.Descriptor(
  name='ListUserRoleMappingsRequest',
  full_name='blueapi.iam.v1.ListUserRoleMappingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subUser', full_name='blueapi.iam.v1.ListUserRoleMappingsRequest.subUser', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=916,
  serialized_end=962,
)


_LISTUSERROLEMAPPINGSRESPONSE = _descriptor.Descriptor(
  name='ListUserRoleMappingsResponse',
  full_name='blueapi.iam.v1.ListUserRoleMappingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userRoleMappings', full_name='blueapi.iam.v1.ListUserRoleMappingsResponse.userRoleMappings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=1050,
)


_MAPROLE = _descriptor.Descriptor(
  name='MapRole',
  full_name='blueapi.iam.v1.MapRole',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='blueapi.iam.v1.MapRole.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='blueapi.iam.v1.MapRole.role', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1094,
)


_CREATEUSERROLEMAPPINGREQUEST = _descriptor.Descriptor(
  name='CreateUserRoleMappingRequest',
  full_name='blueapi.iam.v1.CreateUserRoleMappingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subUser', full_name='blueapi.iam.v1.CreateUserRoleMappingRequest.subUser', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='blueapi.iam.v1.CreateUserRoleMappingRequest.roles', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1183,
)


_CREATEUSERROLEMAPPINGRESPONSE = _descriptor.Descriptor(
  name='CreateUserRoleMappingResponse',
  full_name='blueapi.iam.v1.CreateUserRoleMappingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='blueapi.iam.v1.CreateUserRoleMappingResponse.success', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed', full_name='blueapi.iam.v1.CreateUserRoleMappingResponse.failed', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='blueapi.iam.v1.CreateUserRoleMappingResponse.filters', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1266,
)


_UPDATEUSERROLEMAPPINGREQUEST = _descriptor.Descriptor(
  name='UpdateUserRoleMappingRequest',
  full_name='blueapi.iam.v1.UpdateUserRoleMappingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subUser', full_name='blueapi.iam.v1.UpdateUserRoleMappingRequest.subUser', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='blueapi.iam.v1.UpdateUserRoleMappingRequest.roles', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1268,
  serialized_end=1355,
)


_UPDATEUSERROLEMAPPINGRESPONSE = _descriptor.Descriptor(
  name='UpdateUserRoleMappingResponse',
  full_name='blueapi.iam.v1.UpdateUserRoleMappingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='blueapi.iam.v1.UpdateUserRoleMappingResponse.success', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed', full_name='blueapi.iam.v1.UpdateUserRoleMappingResponse.failed', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='blueapi.iam.v1.UpdateUserRoleMappingResponse.filters', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1357,
  serialized_end=1438,
)


_IPFILTER = _descriptor.Descriptor(
  name='IpFilter',
  full_name='blueapi.iam.v1.IpFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.iam.v1.IpFilter.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='blueapi.iam.v1.IpFilter.scope', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='blueapi.iam.v1.IpFilter.target', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='blueapi.iam.v1.IpFilter.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='blueapi.iam.v1.IpFilter.value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1522,
)


_LISTIPFILTERSREQUEST = _descriptor.Descriptor(
  name='ListIpFiltersRequest',
  full_name='blueapi.iam.v1.ListIpFiltersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1524,
  serialized_end=1546,
)


_CREATEIPFILTERREQUEST = _descriptor.Descriptor(
  name='CreateIpFilterRequest',
  full_name='blueapi.iam.v1.CreateIpFilterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='blueapi.iam.v1.CreateIpFilterRequest.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='blueapi.iam.v1.CreateIpFilterRequest.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rootUser', full_name='blueapi.iam.v1.CreateIpFilterRequest.rootUser', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subUser', full_name='blueapi.iam.v1.CreateIpFilterRequest.subUser', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1548,
  serialized_end=1635,
)


_DELETEIPFILTERREQUEST = _descriptor.Descriptor(
  name='DeleteIpFilterRequest',
  full_name='blueapi.iam.v1.DeleteIpFilterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.iam.v1.DeleteIpFilterRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1637,
  serialized_end=1672,
)

_LISTPERMISSIONSRESPONSE.fields_by_name['permissions'].message_type = api_dot_rbac__pb2._PERMISSION
_LISTROLESRESPONSE.fields_by_name['roles'].message_type = api_dot_rbac__pb2._ROLE
_LISTUSERROLEMAPPINGSRESPONSE.fields_by_name['userRoleMappings'].message_type = api_dot_rbac__pb2._USERROLEMAPPING
_CREATEUSERROLEMAPPINGREQUEST.fields_by_name['roles'].message_type = _MAPROLE
_UPDATEUSERROLEMAPPINGREQUEST.fields_by_name['roles'].message_type = _MAPROLE
DESCRIPTOR.message_types_by_name['WhoAmIRequest'] = _WHOAMIREQUEST
DESCRIPTOR.message_types_by_name['ListUsersRequest'] = _LISTUSERSREQUEST
DESCRIPTOR.message_types_by_name['GetUserRequest'] = _GETUSERREQUEST
DESCRIPTOR.message_types_by_name['CreateUserRequest'] = _CREATEUSERREQUEST
DESCRIPTOR.message_types_by_name['DeleteUserRequest'] = _DELETEUSERREQUEST
DESCRIPTOR.message_types_by_name['ListApiClientsRequest'] = _LISTAPICLIENTSREQUEST
DESCRIPTOR.message_types_by_name['CreateApiClientRequest'] = _CREATEAPICLIENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteApiClientRequest'] = _DELETEAPICLIENTREQUEST
DESCRIPTOR.message_types_by_name['ListPermissionsRequest'] = _LISTPERMISSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListPermissionsResponse'] = _LISTPERMISSIONSRESPONSE
DESCRIPTOR.message_types_by_name['ListRolesRequest'] = _LISTROLESREQUEST
DESCRIPTOR.message_types_by_name['ListRolesResponse'] = _LISTROLESRESPONSE
DESCRIPTOR.message_types_by_name['CreateRoleRequest'] = _CREATEROLEREQUEST
DESCRIPTOR.message_types_by_name['UpdateRoleRequest'] = _UPDATEROLEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRoleRequest'] = _DELETEROLEREQUEST
DESCRIPTOR.message_types_by_name['ListUserRoleMappingsRequest'] = _LISTUSERROLEMAPPINGSREQUEST
DESCRIPTOR.message_types_by_name['ListUserRoleMappingsResponse'] = _LISTUSERROLEMAPPINGSRESPONSE
DESCRIPTOR.message_types_by_name['MapRole'] = _MAPROLE
DESCRIPTOR.message_types_by_name['CreateUserRoleMappingRequest'] = _CREATEUSERROLEMAPPINGREQUEST
DESCRIPTOR.message_types_by_name['CreateUserRoleMappingResponse'] = _CREATEUSERROLEMAPPINGRESPONSE
DESCRIPTOR.message_types_by_name['UpdateUserRoleMappingRequest'] = _UPDATEUSERROLEMAPPINGREQUEST
DESCRIPTOR.message_types_by_name['UpdateUserRoleMappingResponse'] = _UPDATEUSERROLEMAPPINGRESPONSE
DESCRIPTOR.message_types_by_name['IpFilter'] = _IPFILTER
DESCRIPTOR.message_types_by_name['ListIpFiltersRequest'] = _LISTIPFILTERSREQUEST
DESCRIPTOR.message_types_by_name['CreateIpFilterRequest'] = _CREATEIPFILTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteIpFilterRequest'] = _DELETEIPFILTERREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WhoAmIRequest = _reflection.GeneratedProtocolMessageType('WhoAmIRequest', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.WhoAmIRequest)
  })
_sym_db.RegisterMessage(WhoAmIRequest)

ListUsersRequest = _reflection.GeneratedProtocolMessageType('ListUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.ListUsersRequest)
  })
_sym_db.RegisterMessage(ListUsersRequest)

GetUserRequest = _reflection.GeneratedProtocolMessageType('GetUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.GetUserRequest)
  })
_sym_db.RegisterMessage(GetUserRequest)

CreateUserRequest = _reflection.GeneratedProtocolMessageType('CreateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.CreateUserRequest)
  })
_sym_db.RegisterMessage(CreateUserRequest)

DeleteUserRequest = _reflection.GeneratedProtocolMessageType('DeleteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.DeleteUserRequest)
  })
_sym_db.RegisterMessage(DeleteUserRequest)

ListApiClientsRequest = _reflection.GeneratedProtocolMessageType('ListApiClientsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPICLIENTSREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.ListApiClientsRequest)
  })
_sym_db.RegisterMessage(ListApiClientsRequest)

CreateApiClientRequest = _reflection.GeneratedProtocolMessageType('CreateApiClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPICLIENTREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.CreateApiClientRequest)
  })
_sym_db.RegisterMessage(CreateApiClientRequest)

DeleteApiClientRequest = _reflection.GeneratedProtocolMessageType('DeleteApiClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPICLIENTREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.DeleteApiClientRequest)
  })
_sym_db.RegisterMessage(DeleteApiClientRequest)

ListPermissionsRequest = _reflection.GeneratedProtocolMessageType('ListPermissionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.ListPermissionsRequest)
  })
_sym_db.RegisterMessage(ListPermissionsRequest)

ListPermissionsResponse = _reflection.GeneratedProtocolMessageType('ListPermissionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSRESPONSE,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.ListPermissionsResponse)
  })
_sym_db.RegisterMessage(ListPermissionsResponse)

ListRolesRequest = _reflection.GeneratedProtocolMessageType('ListRolesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.ListRolesRequest)
  })
_sym_db.RegisterMessage(ListRolesRequest)

ListRolesResponse = _reflection.GeneratedProtocolMessageType('ListRolesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESRESPONSE,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.ListRolesResponse)
  })
_sym_db.RegisterMessage(ListRolesResponse)

CreateRoleRequest = _reflection.GeneratedProtocolMessageType('CreateRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEROLEREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.CreateRoleRequest)
  })
_sym_db.RegisterMessage(CreateRoleRequest)

UpdateRoleRequest = _reflection.GeneratedProtocolMessageType('UpdateRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROLEREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.UpdateRoleRequest)
  })
_sym_db.RegisterMessage(UpdateRoleRequest)

DeleteRoleRequest = _reflection.GeneratedProtocolMessageType('DeleteRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEROLEREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.DeleteRoleRequest)
  })
_sym_db.RegisterMessage(DeleteRoleRequest)

ListUserRoleMappingsRequest = _reflection.GeneratedProtocolMessageType('ListUserRoleMappingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERROLEMAPPINGSREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.ListUserRoleMappingsRequest)
  })
_sym_db.RegisterMessage(ListUserRoleMappingsRequest)

ListUserRoleMappingsResponse = _reflection.GeneratedProtocolMessageType('ListUserRoleMappingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERROLEMAPPINGSRESPONSE,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.ListUserRoleMappingsResponse)
  })
_sym_db.RegisterMessage(ListUserRoleMappingsResponse)

MapRole = _reflection.GeneratedProtocolMessageType('MapRole', (_message.Message,), {
  'DESCRIPTOR' : _MAPROLE,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.MapRole)
  })
_sym_db.RegisterMessage(MapRole)

CreateUserRoleMappingRequest = _reflection.GeneratedProtocolMessageType('CreateUserRoleMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERROLEMAPPINGREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.CreateUserRoleMappingRequest)
  })
_sym_db.RegisterMessage(CreateUserRoleMappingRequest)

CreateUserRoleMappingResponse = _reflection.GeneratedProtocolMessageType('CreateUserRoleMappingResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERROLEMAPPINGRESPONSE,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.CreateUserRoleMappingResponse)
  })
_sym_db.RegisterMessage(CreateUserRoleMappingResponse)

UpdateUserRoleMappingRequest = _reflection.GeneratedProtocolMessageType('UpdateUserRoleMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERROLEMAPPINGREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.UpdateUserRoleMappingRequest)
  })
_sym_db.RegisterMessage(UpdateUserRoleMappingRequest)

UpdateUserRoleMappingResponse = _reflection.GeneratedProtocolMessageType('UpdateUserRoleMappingResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERROLEMAPPINGRESPONSE,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.UpdateUserRoleMappingResponse)
  })
_sym_db.RegisterMessage(UpdateUserRoleMappingResponse)

IpFilter = _reflection.GeneratedProtocolMessageType('IpFilter', (_message.Message,), {
  'DESCRIPTOR' : _IPFILTER,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.IpFilter)
  })
_sym_db.RegisterMessage(IpFilter)

ListIpFiltersRequest = _reflection.GeneratedProtocolMessageType('ListIpFiltersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTIPFILTERSREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.ListIpFiltersRequest)
  })
_sym_db.RegisterMessage(ListIpFiltersRequest)

CreateIpFilterRequest = _reflection.GeneratedProtocolMessageType('CreateIpFilterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEIPFILTERREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.CreateIpFilterRequest)
  })
_sym_db.RegisterMessage(CreateIpFilterRequest)

DeleteIpFilterRequest = _reflection.GeneratedProtocolMessageType('DeleteIpFilterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIPFILTERREQUEST,
  '__module__' : 'iam.v1.iam_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.iam.v1.DeleteIpFilterRequest)
  })
_sym_db.RegisterMessage(DeleteIpFilterRequest)


DESCRIPTOR._options = None

_IAM = _descriptor.ServiceDescriptor(
  name='Iam',
  full_name='blueapi.iam.v1.Iam',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\211\001\022:(BETA) IAM API. Base URL: https://api.alphaus.cloud/m/blue\032K\n\022Service definition\0225https://github.com/alphauslabs/blueapi/tree/main/iam/',
  create_key=_descriptor._internal_create_key,
  serialized_start=1675,
  serialized_end=3958,
  methods=[
  _descriptor.MethodDescriptor(
    name='WhoAmI',
    full_name='blueapi.iam.v1.Iam.WhoAmI',
    index=0,
    containing_service=None,
    input_type=_WHOAMIREQUEST,
    output_type=api_dot_user__pb2._USER,
    serialized_options=b'\202\323\344\223\002\020\022\016/iam/v1/whoami',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUsers',
    full_name='blueapi.iam.v1.Iam.ListUsers',
    index=1,
    containing_service=None,
    input_type=_LISTUSERSREQUEST,
    output_type=api_dot_user__pb2._USER,
    serialized_options=b'\202\323\344\223\002\017\022\r/iam/v1/users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUser',
    full_name='blueapi.iam.v1.Iam.GetUser',
    index=2,
    containing_service=None,
    input_type=_GETUSERREQUEST,
    output_type=api_dot_user__pb2._USER,
    serialized_options=b'\202\323\344\223\002\024\022\022/iam/v1/users/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateUser',
    full_name='blueapi.iam.v1.Iam.CreateUser',
    index=3,
    containing_service=None,
    input_type=_CREATEUSERREQUEST,
    output_type=api_dot_user__pb2._USER,
    serialized_options=b'\202\323\344\223\002\022\"\r/iam/v1/users:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUser',
    full_name='blueapi.iam.v1.Iam.DeleteUser',
    index=4,
    containing_service=None,
    input_type=_DELETEUSERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\024*\022/iam/v1/users/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListApiClients',
    full_name='blueapi.iam.v1.Iam.ListApiClients',
    index=5,
    containing_service=None,
    input_type=_LISTAPICLIENTSREQUEST,
    output_type=api_dot_apiclient__pb2._APICLIENT,
    serialized_options=b'\202\323\344\223\002\024\022\022/iam/v1/apiclients',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateApiClient',
    full_name='blueapi.iam.v1.Iam.CreateApiClient',
    index=6,
    containing_service=None,
    input_type=_CREATEAPICLIENTREQUEST,
    output_type=api_dot_apiclient__pb2._APICLIENT,
    serialized_options=b'\202\323\344\223\002\027\"\022/iam/v1/apiclients:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteApiClient',
    full_name='blueapi.iam.v1.Iam.DeleteApiClient',
    index=7,
    containing_service=None,
    input_type=_DELETEAPICLIENTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\031*\027/iam/v1/apiclients/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPermissions',
    full_name='blueapi.iam.v1.Iam.ListPermissions',
    index=8,
    containing_service=None,
    input_type=_LISTPERMISSIONSREQUEST,
    output_type=_LISTPERMISSIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/iam/v1/permissions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRoles',
    full_name='blueapi.iam.v1.Iam.ListRoles',
    index=9,
    containing_service=None,
    input_type=_LISTROLESREQUEST,
    output_type=_LISTROLESRESPONSE,
    serialized_options=b'\202\323\344\223\002\017\022\r/iam/v1/roles',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRole',
    full_name='blueapi.iam.v1.Iam.CreateRole',
    index=10,
    containing_service=None,
    input_type=_CREATEROLEREQUEST,
    output_type=api_dot_rbac__pb2._ROLE,
    serialized_options=b'\202\323\344\223\002\022\"\r/iam/v1/roles:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRole',
    full_name='blueapi.iam.v1.Iam.UpdateRole',
    index=11,
    containing_service=None,
    input_type=_UPDATEROLEREQUEST,
    output_type=api_dot_rbac__pb2._ROLE,
    serialized_options=b'\202\323\344\223\002%\032 /iam/v1/roles/{namespace}/{name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRole',
    full_name='blueapi.iam.v1.Iam.DeleteRole',
    index=12,
    containing_service=None,
    input_type=_DELETEROLEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\"* /iam/v1/roles/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUserRoleMappings',
    full_name='blueapi.iam.v1.Iam.ListUserRoleMappings',
    index=13,
    containing_service=None,
    input_type=_LISTUSERROLEMAPPINGSREQUEST,
    output_type=_LISTUSERROLEMAPPINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/iam/v1/userroles',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateUserRoleMapping',
    full_name='blueapi.iam.v1.Iam.CreateUserRoleMapping',
    index=14,
    containing_service=None,
    input_type=_CREATEUSERROLEMAPPINGREQUEST,
    output_type=_CREATEUSERROLEMAPPINGRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\"\021/iam/v1/userroles:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateUserRoleMapping',
    full_name='blueapi.iam.v1.Iam.UpdateUserRoleMapping',
    index=15,
    containing_service=None,
    input_type=_UPDATEUSERROLEMAPPINGREQUEST,
    output_type=_UPDATEUSERROLEMAPPINGRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\032\021/iam/v1/userroles:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListIpFilters',
    full_name='blueapi.iam.v1.Iam.ListIpFilters',
    index=16,
    containing_service=None,
    input_type=_LISTIPFILTERSREQUEST,
    output_type=_IPFILTER,
    serialized_options=b'\202\323\344\223\002\023\022\021/iam/v1/ipfilters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateIpFilter',
    full_name='blueapi.iam.v1.Iam.CreateIpFilter',
    index=17,
    containing_service=None,
    input_type=_CREATEIPFILTERREQUEST,
    output_type=_IPFILTER,
    serialized_options=b'\202\323\344\223\002\026\"\021/iam/v1/ipfilters:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteIpFilter',
    full_name='blueapi.iam.v1.Iam.DeleteIpFilter',
    index=18,
    containing_service=None,
    input_type=_DELETEIPFILTERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\030*\026/iam/v1/ipfilters/{id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IAM)

DESCRIPTOR.services_by_name['Iam'] = _IAM

# @@protoc_insertion_point(module_scope)
